pub struct AnnotationDiscovery { /* private fields */ }Expand description
Discovers annotations from program AST and imports
Implementations
Sourceimpl AnnotationDiscovery
impl AnnotationDiscovery
Sourcepub fn discover_from_program(&mut self, program: &Program)
pub fn discover_from_program(&mut self, program: &Program)
Discover annotations from a parsed program
Sourcepub fn discover_from_imports_with_cache(
&mut self,
program: &Program,
current_file: &Path,
module_cache: &ModuleCache,
workspace_root: Option<&Path>,
)
pub fn discover_from_imports_with_cache( &mut self, program: &Program, current_file: &Path, module_cache: &ModuleCache, workspace_root: Option<&Path>, )
Discover annotations from imported modules using module cache
Looks at import statements in the program and loads the corresponding modules to discover their exported annotations.
NOTE: Annotations are now fully defined in Shape stdlib, not hardcoded in Rust. The LSP discovers annotations from:
- Local
annotation ... { ... }definitions in the current file - Imported modules (including stdlib/core/annotations/, stdlib/finance/, etc.)
Sourcepub fn discover_from_imports(&mut self, _program: &Program)
pub fn discover_from_imports(&mut self, _program: &Program)
Discover annotations from imported modules (simple version without module cache)
NOTE: Without module cache, no annotations are discovered. Use discover_from_imports_with_cache() for full annotation discovery.
Sourcepub fn all_annotations(&self) -> Vec<&AnnotationInfo>
pub fn all_annotations(&self) -> Vec<&AnnotationInfo>
Get all discovered annotations
Sourcepub fn is_defined(&self, name: &str) -> bool
pub fn is_defined(&self, name: &str) -> bool
Check if an annotation is defined
Sourcepub fn get(&self, name: &str) -> Option<&AnnotationInfo>
pub fn get(&self, name: &str) -> Option<&AnnotationInfo>
Get information about a specific annotation