Module context

Module context 

Context analysis for intelligent completions

Determines the completion context based on cursor position and surrounding text.

Enums

ArgumentContext
Detailed context about argument position
CompletionContext
Completion context based on cursor position

Functions

analyze_context
Analyze the text and position to determine completion context
detect_type_alias_override_context_pub
Public API: check if cursor is inside a type alias override, returning the base type name
is_inside_interpolation_expression
Returns true when cursor is inside an interpolation expression body, such as f"{expr}", f"${expr}", or f#"{expr}".