Module document

Module document 

Document management for LSP

Tracks open documents, their content, and version numbers for incremental updates.

Structs

Document
A document in the workspace with its content and metadata
DocumentManager
Manages all open documents in the workspace