pub struct PositionMap { /* private fields */ }Expand description
Maps positions between a Shape source file and a virtual foreign document.
Implementations
Sourceimpl PositionMap
impl PositionMap
pub fn new(body_span: Span, source: &str) -> Self
Sourcepub fn shape_to_virtual(&self, pos: Position) -> Option<Position>
pub fn shape_to_virtual(&self, pos: Position) -> Option<Position>
Map a Shape source position to virtual document position, if inside the body.
Sourcepub fn virtual_to_shape(&self, pos: Position) -> Option<Position>
pub fn virtual_to_shape(&self, pos: Position) -> Option<Position>
Map a virtual document position back to Shape source position.
Sourcepub fn virtual_range_to_shape(&self, range: Range) -> Option<Range>
pub fn virtual_range_to_shape(&self, range: Range) -> Option<Range>
Map a virtual document range back to a Shape source range.
Sourcepub fn body_start_offset(&self) -> usize
pub fn body_start_offset(&self) -> usize
The byte offset where the foreign body starts in the Shape source.
Sourcepub fn header_lines(&self) -> u32
pub fn header_lines(&self) -> u32
Number of synthetic header lines in the virtual document.