get_hover

Function get_hover 

pub fn get_hover(
    text: &str,
    position: Position,
    module_cache: Option<&ModuleCache>,
    current_file: Option<&Path>,
    cached_program: Option<&Program>,
) -> Option<Hover>
Get hover information for a position in the document.

When cached_program is provided, it is used as a fallback AST when the current source text fails to parse (e.g., user is mid-edit).