Context analysis for intelligent completions
Determines the completion context based on cursor position and surrounding text.
Enums
- Argument
Context - Detailed context about argument position
- Completion
Context - Completion context based on cursor position
Functions
- analyze_
context - Analyze the text and position to determine completion context
- detect_
type_ alias_ override_ context_ pub - Public API: check if cursor is inside a type alias override, returning the base type name
- is_
inside_ interpolation_ expression - Returns true when cursor is inside an interpolation expression body,
such as
f"{expr}",f"${expr}", orf#"{expr}".