Diagnostics conversion from Shape errors to LSP diagnostics
Structs
- LspError
Renderer - LSP Error Renderer - converts structured errors to LSP Diagnostics
Functions
- borrow_
analysis_ to_ diagnostics - Convert structured MIR borrow errors into LSP diagnostics.
- code_
description_ for - W2.3 / 1.17 — build a
CodeDescriptionfor a Shape error code string. - diagnostic_
tags_ for - W2.3 / 1.19 — derive LSP
DiagnosticTags from a shape diagnostic. - enrich_
diagnostics_ with_ code_ metadata - W2.3 — backfill
code_description(1.17) +tags(1.19) on a diagnostic batch produced by the per-validator pipeline. - error_
to_ diagnostic - Convert Shape errors to LSP diagnostics
- error_
to_ diagnostic_ with_ uri - Convert Shape errors to LSP diagnostics with optional URI for structured errors
- validate_
annotations - Validate annotations in a program and return diagnostics for any issues
- validate_
async_ join - Validate async join usage:
await joinmust be inside an async function. - validate_
async_ structured_ concurrency - Validate structured concurrency constructs (
async let,async scope,for await) are only used inside async function bodies. - validate_
color_ rgb_ range - Validate Content API calls.
- validate_
comptime_ builtins_ context - Diagnose comptime-only builtins called outside a
comptime { }block. - validate_
comptime_ overrides - Validate type alias overrides: only comptime fields can be overridden.
- validate_
comptime_ side_ effects - Warn when a comptime block contains side-effecting expressions.
- validate_
foreign_ function_ types - Validate that foreign function parameters and return types are explicitly annotated.
- validate_
interpolation_ format_ specs - Validate formatted interpolation specs in
f"..."string literals. - validate_
trait_ bounds - Validate trait bound satisfaction in impl blocks and function type parameters.
- validate_
unused_ imports - W2.3 / 1.19 — detect unused imports and emit
W0102diagnostics tagged withDiagnosticTag::UNNECESSARY(via the metadata enricher).